@@ -5,7 +5,7 @@
  * fractint license conditions, blah blah blah.
  */
 
-#include <fractint.h>
+#include "port.h"
 
 unsigned long savedmask;
 long linitx, linity;
