@@ -5,20 +5,13 @@
  * fractint license conditions, blah blah blah.
  */
 
-#include "fractint.h"
+#include "port.h"
+#include "prototyp.h"
 #include "fractype.h"
 
-extern _CMPLX init, parm, new;
-
-extern int coloriter, oldcoloriter, realcoloriter, periodicitycheck, reset_periodicity,
-    fractype, kbdcount, dotmode, show_orbit, orbit_ptr, potflag, maxit,
-    inside, outside, fpu;
-
-extern double closenuff, magnitude, rqlim;
-
 static int tmp_word, inside_color, periodicity_color;
 
-calcmandfpasmstart() {
+void calcmandfpasmstart(void) {
     if (inside<0) {
 	inside_color = maxit;
     } else {
@@ -31,13 +24,12 @@ calcmandfpasmstart() {
 	periodicity_color = inside_color;
     }
     oldcoloriter = 0;
-    return 0;
 }
 
 #define ABS(x) ((x)>0?(x):-(x))
 #define close 0.01
 
-calcmandfpasm() {
+long calcmandfpasm(void) {
     int cx;
     int savedand;
     double x,y,x2, y2, xy, Cx, Cy, savedx, savedy;
