@@ -11,13 +11,9 @@
 #ifndef XFRACT
 #include <dos.h>
 #endif
-#include "fractint.h"
 
-extern int sxdots, sydots, colors;
-extern int dotmode;	  /* video access method, 11 if really disk video */
-extern int diskisactive;  /* set by fractint to disable re-init */
-extern int debugflag;
-extern int diskflag;
+#include "port.h"
+#include "prototyp.h"
 
 #define BOXROW	 6
 #define BOXCOL	 11
@@ -85,7 +81,7 @@ int targa_startdisk(FILE *targafp,int overhead)
    return (i);
 }
 
-int _fastcall near common_startdisk(int newrowsize, int newcolsize, int colors)
+int _fastcall near common_startdisk(long newrowsize, long newcolsize, int colors)
 {
    int i,success;
    long memorysize;
