@@ -1,19 +1,28 @@
+#ifndef EXTERNS_H
+#define EXTERNS_H
+
+#ifndef DEBUG
+#define DEBUG 1
+#endif
+
+
 /* keep var names in column 30 for sorting via sort /+30 <in >out */
 extern int                   active_system;
 extern int                   adapter;
 extern ALTERNATE far         alternatemath[];
 extern int                   Ambient;
-extern int                   andcolor; 
+extern int                   andcolor;
 extern struct MP             Ans;
 extern int                   Ap1deg;
 extern int                   AplusOne;
 extern int                   askvideo;
 extern float                 aspectdrift;
-extern int                   attractors;  
-extern int                   attrperiod[];   
-extern _CMPLX                attr[];  
+extern int                   attractors;
+extern int                   attrperiod[];
+extern _CMPLX                attr[];
 extern int                   autobrowse;
 extern char                  autoname[];
+extern char                  autoshowdot;
 extern int                   AutoStereo_depth;
 extern double                AutoStereo_width;
 extern BYTE                  back_color[];
@@ -64,10 +73,7 @@ extern int                   colorstate;
 extern int                   color_bright;
 extern int                   color_dark;
 extern int                   color_medium;
-extern char                  CommandComment1[57];
-extern char                  CommandComment2[57];
-extern char                  CommandComment3[57];
-extern char                  CommandComment4[57];
+extern char                  CommandComment[4][MAXCMT];
 extern char                  CommandFile[80];
 extern char                  CommandName[ITEMNAMELEN + 1];
 extern int                   comparegif;
@@ -87,7 +93,7 @@ extern int                   daclearn;
 extern double                ddelmin;
 extern int                   debugflag;
 extern int                   decimals;
-extern BYTE                  decoderline[];                     
+extern BYTE                  decoderline[];
 extern int                   decomp[];
 extern int                   degree;
 extern long                  delmin;
@@ -108,7 +114,7 @@ extern int                   diskflag;
 extern int                   diskisactive;
 extern int                   diskvideo;
 extern int                   display3d;
-extern int                   distest;
+extern long                  distest;
 extern int                   distestwidth;
 extern float                 distfp;
 extern int                   Distribution;
@@ -129,6 +135,7 @@ extern BYTE                  exitmode;
 extern SEGTYPE               extraseg;
 extern int                   eyeseparation;
 extern float                 eyesfp;
+extern int                   fastrestore;
 extern long                  FgHalf;
 extern double                fgLimit;
 extern long                  FgOne;
@@ -143,7 +150,6 @@ extern int                   fillcolor;
 extern float                 finalaspectratio;
 extern int                   finattract;
 extern int                   finishrow;
-extern int                   first_err;   
 extern int                   first_init;
 extern char                  floatflag;
 extern double                floatmax;
@@ -177,7 +183,7 @@ extern int                   hasinverse;
 extern int                   haze;
 extern unsigned int          height;
 extern float                 heightfp;
-extern int		     helpmode;
+extern int                   helpmode;
 extern HISTORY far *         history;
 extern char                  IFSFileName[];
 extern char                  IFSName[];
@@ -197,7 +203,10 @@ extern FCODE                 insufficient_ifs_mem[];
 extern int                   integerfractal;
 extern double                inversion[];
 extern int                   invert;
+extern int                   istruecolor;
+extern int                   ixstart;
 extern int                   ixstop;
+extern int                   iystart;
 extern int                   iystop;
 extern char *                JIIMleftright[];
 extern char *                JIIMmethod[];
@@ -207,8 +216,10 @@ extern int                   julibrot;
 extern int                   kbdcount;
 extern int                   keybuffer;
 extern long                  l16triglim;
+extern int                   LastInitOp;
+extern unsigned              LastOp;
 extern int                   lastorbittype;
-extern _LCMPLX               lattr[];  
+extern _LCMPLX               lattr[];
 extern long                  lclosenuff;
 extern _LCMPLX               lcoefficient;
 extern char                  LFileName[];
@@ -224,7 +235,10 @@ extern long                  lmagnitud;
 extern char                  LName[];
 extern _LCMPLX               lnew;
 extern int                   loaded3d;
-extern int                   LogFlag;
+extern int                   LodPtr;
+extern int                   Log_Calc;
+extern int                   Log_Fly_Calc;
+extern long                  LogFlag;
 extern BYTE far *            LogTable;
 extern _LCMPLX               lold;
 extern _LCMPLX *             longparm;
@@ -234,11 +248,12 @@ extern _LCMPLX               lparm;
 extern int                   LPTNumber;
 extern long                  ltempsqrx;
 extern long                  ltempsqry;
-extern _LCMPLX               ltmp;                           
+extern _LCMPLX               ltmp;
 extern long far *            lx0;
 extern long far *            lx1;
 extern long far *            ly0;
 extern long far *            ly1;
+extern int                   lzw[2];
 extern long                  l_at_rad;
 extern MATRIX                m;
 extern int                   made_dsktemp;
@@ -247,11 +262,15 @@ extern enum Major            major_method;
 extern BYTE far *            mapdacbox;
 extern int                   mapset;
 extern char                  MAP_name[];
+extern int                   matherr_ct;
+extern double                math_tol[2];
 extern int                   maxcolor;
 extern long                  maxct;
 extern char                  maxfn;
 extern long                  maxit;
-extern int                   MaxLTSize;
+extern long                  MaxLTSize;
+extern unsigned              Max_Args;
+extern unsigned              Max_Ops;
 extern long                  maxptr;
 extern int                   max_colors;
 extern int                   max_kbdcount;
@@ -283,7 +302,7 @@ extern int                   no_sub_images;
 extern int                   no_mag_calc;
 extern int                   numaffine;
 extern unsigned              numcolors;
-extern int                   numtrigfn;
+extern const int             numtrigfn;
 extern int                   num_fractal_types;
 extern int                   num_worklist;
 extern int                   nxtscreenflag;
@@ -294,7 +313,7 @@ extern long                  oldcoloriter;
 extern BYTE                  olddacbox[256][3];
 extern int                   old_demm_colors;
 extern int                   orbitsave;
-extern int                   orbit_color; 
+extern int                   orbit_color;
 extern int                   orbit_delay;
 extern int                   orbit_ptr;
 extern float                 originfp;
@@ -303,11 +322,12 @@ extern void (*               outln_cleanup) (void);
 extern int                   outside;
 extern int                   overflow;
 extern int                   overlay3d;
-extern char                  xoverwrite;
+extern char                  overwrite;
 extern double                param[];
 extern _CMPLX                parm2;
 extern _CMPLX                parm;
 extern int                   passes;
+extern int                   patchlevel;
 extern int                   periodicitycheck;
 extern struct fls far *      pfls;
 extern int                   pixelpi;
@@ -316,6 +336,7 @@ extern double                plotmx1;
 extern double                plotmx2;
 extern double                plotmy1;
 extern double                plotmy2;
+extern unsigned              posp;
 extern int                   pot16bit;
 extern int                   potflag;
 extern double                potparam[];
@@ -347,6 +368,7 @@ extern char                  PrintName[];
 extern int                   Print_To_File;
 extern int                   pseudox;
 extern int                   pseudoy;
+extern void (_fastcall *     putcolor)(int,int,int);
 extern _CMPLX                pwr;
 extern double                qc;
 extern double                qci;
@@ -360,6 +382,7 @@ extern char                  ray_name[];
 extern char                  readname[];
 extern long                  realcoloriter;
 extern int                   reallyega;
+extern char                  recordcolors;
 extern int                   red_bright;
 extern int                   red_crop_left;
 extern int                   red_crop_right;
@@ -370,7 +393,7 @@ extern char far *            resume_info;
 extern int                   resume_len;
 extern int                   resuming;
 extern int                   rflag;
-extern char                  rlebuf[];    
+extern char                  rlebuf[];
 extern int                   root;
 extern _CMPLX *              roots;
 extern int                   rotate_hi;
@@ -386,18 +409,21 @@ extern _CMPLX                SaveC;
 extern int                   savedac;
 extern char                  savename[];
 extern long                  saveticks;
-extern int far *             save_orbit;  
+extern int far *             save_orbit;
 extern int                   save_release;
 extern int                   save_system;
 extern float                 screenaspect;
 extern char                  scrnfile[];
+extern struct SearchPath     searchfor;
 extern char                  showbox;
 extern int                   showdot;
 extern int                   showfile;
 extern int                   show_orbit;
 extern double                sinx;
-extern short                 skipxdots; 
-extern short                 skipydots; 
+extern int                   sizedot;
+extern short far             sizeofstring[];
+extern short                 skipxdots;
+extern short                 skipydots;
 extern int                   slides;
 extern int                   Slope;
 extern int                   soundflag;
@@ -405,9 +431,11 @@ extern char                  speed_prompt[];
 extern void (_fastcall*      standardplot)(int,int,int);
 extern char                  start_showorbit;
 extern int                   started_resaves;
-extern _CMPLX                staticroots[]; 
+extern _CMPLX                staticroots[];
 extern char                  stdcalcmode;
 extern char                  stereomapname[];
+extern int                   StoPtr;
+extern int                   stoppass;
 extern unsigned int          strlocn[];
 extern BYTE                  suffix[];
 extern char                  supervga_list;
@@ -456,6 +484,7 @@ extern char                  s_cantcreate[];
 extern char                  s_cantfind[];
 extern char                  s_cantunderstand[];
 extern char                  s_cantwrite[];
+extern char                  s_ceil[];
 extern char                  s_centermag[];
 extern char                  s_cga[];
 extern char                  s_coarse[];
@@ -484,7 +513,6 @@ extern char                  s_egamono[];
 extern char                  s_ega[];
 extern char                  s_epscross[];
 extern char                  s_epsf[];
-extern char far              s_escapetoabort[];
 extern char                  s_exitmode[];
 extern char                  s_exitnoask[];
 extern char                  s_exp[];
@@ -494,6 +522,7 @@ extern char                  s_filltype[];
 extern char                  s_finattract[];
 extern char                  s_flip[];
 extern char                  s_float[];
+extern char                  s_floor[];
 extern char                  s_fn1[];
 extern char                  s_fn2[];
 extern char                  s_fn3[];
@@ -532,10 +561,14 @@ extern char                  s_lightsource[];
 extern char                  s_linefeed[];
 extern char                  s_lname[];
 extern char                  s_logmap[];
+extern char                  s_logmode[];
 extern char                  s_log[];
 extern char                  s_longitude[];
 extern char                  s_makedoc[];
 extern char                  s_makemig[];
+extern char                  s_makepar[];
+extern char                  s_manh[];
+extern char                  s_manr[];
 extern char                  s_map[];
 extern char                  s_maxcolorres[];
 extern char                  s_maxiter[];
@@ -588,12 +621,14 @@ extern char                  s_reset[];
 extern char                  s_rleps[];
 extern char                  s_rotation[];
 extern char                  s_roughness[];
+extern char                  s_round[];
 extern char                  s_rseed[];
 extern char                  s_savename[];
 extern char                  s_savetime[];
 extern char                  s_scalexyz[];
 extern char                  s_showbox[];
 extern char                  s_showdot[];
+extern char                  s_showorbit[];
 extern char                  s_sinh[];
 extern char                  s_sin[];
 extern char                  s_smoothing[];
@@ -617,6 +652,7 @@ extern char                  s_title[];
 extern char                  s_tplus[];
 extern char                  s_translate[];
 extern char                  s_transparent[];
+extern char                  s_trunc[];
 extern char                  s_type[];
 extern char                  s_usegrayscale[];
 extern char                  s_vesadetect[];
@@ -641,8 +677,8 @@ extern int                   tabmode;
 extern int                   Targa_Out;
 extern int                   Targa_Overlay;
 extern char                  temp1[];
-extern double                tempsqrx;  
-extern double                tempsqry;  
+extern double                tempsqrx;
+extern double                tempsqry;
 extern BYTE                  teststring[];
 extern int                   textaddr;
 extern int                   textcbase;
@@ -651,11 +687,11 @@ extern int                   textrbase;
 extern int                   textrow;
 extern int                   textsafe2;
 extern int                   textsafe;
-extern int                   text_type;  
+extern int                   text_type;
 extern unsigned far *        tga16;
 extern long far *            tga32;
 extern char                  three_pass;
-extern double                threshold; 
+extern double                threshold;
 extern int                   timedsave;
 extern int                   timerflag;
 extern long                  timer_interval;
@@ -664,13 +700,16 @@ extern _CMPLX                tmp;
 extern char                  tempdir[];
 extern double                toosmall;
 extern int                   totpasses;
+extern long                  total_formula_mem;
 extern int                   TPlusErr;
 extern int                   transparent[];
 extern BYTE                  trigndx[];
+extern int                   truecolor;
 extern char                  tstack[];
 extern double                twopi;
 extern VOIDFARPTR            typespecific_workarea;
 extern char                  useinitorbit;
+extern BYTE                  used_extra;
 extern BYTE                  usemag;
 extern int                   uses_p1;
 extern int                   uses_p2;
@@ -679,7 +718,7 @@ extern int                   use_old_distest;
 extern int                   use_old_period;
 extern int                   using_jiim;
 extern int                   usr_biomorph;
-extern int                   usr_distest;
+extern long                  usr_distest;
 extern char                  usr_floatflag;
 extern int                   usr_periodicitycheck;
 extern char                  usr_stdcalcmode;
@@ -695,6 +734,7 @@ extern float                 viewreduction;
 extern int                   viewwindow;
 extern int                   viewxdots;
 extern int                   viewydots;
+extern unsigned              vsp;
 extern int                   vxdots;
 extern int                   whichimage;
 extern float                 widthfp;
@@ -745,3 +785,5 @@ extern int                   zoomoff;
 extern int                   zrotate;
 extern double                zskew;
 extern double                zwidth;
+
+#endif
