@@ -16,9 +16,9 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/time.h>
-#include "fractint.h"
-#include "prototyp.h"
 
+#include "port.h"
+#include "prototyp.h"
 int overflow = 0;
 
 int boxx[2304], boxy[1024];
@@ -321,7 +321,7 @@ int delaytime;
     static struct timeval delay;
     delay.tv_sec = delaytime/1000;
     delay.tv_usec = (delaytime%1000)*1000;
-#ifdef __SVR4
+#if defined( __SVR4) || defined(LINUX)
     (void) select(0, (fd_set *) 0, (fd_set *) 0, (fd_set *) 0, &delay);
 #else
     (void) select(0, (int *) 0, (int *) 0, (int *) 0, &delay);
@@ -445,11 +445,11 @@ char *a, *b;
     return strcmp(a,b);
 }
 
-void
+int 
 far_stricmp(a,b)
 char *a,*b;
 {
-    stricmp(a,b);
+   return stricmp(a,b);
 }
 
 int
@@ -471,7 +471,7 @@ void
 far_memset ( a,c,len)
 VOIDFARPTR a;
 int c;
-int len;
+unsigned int len;
 {
     memset(a,c,len);
 }
@@ -725,6 +725,14 @@ decode_fractal_info(info,dir)
     getInt(&info->bflength,&bufPtr,dir);
     getInt(&info->yadjust,&bufPtr,dir); 
     getInt(&info->old_demm_colors,&bufPtr,dir);
+    getLong(&info->logmap,&bufPtr,dir);
+    getLong(&info->distest,&bufPtr,dir);
+    getDouble(&info->dinvert[0],&bufPtr,dir);
+    getDouble(&info->dinvert[1],&bufPtr,dir);
+    getDouble(&info->dinvert[2],&bufPtr,dir);
+    getInt(&info->logcalc,&bufPtr,dir);
+    getInt(&info->stoppass,&bufPtr,dir);
+
     for (i=0;i<(sizeof(info->future)/sizeof(short));i++) {
         getInt(&info->future[i],&bufPtr,dir);
     }   
