@@ -18,6 +18,19 @@
 
 /* Revision history:  */
 
+/* 15 Mar 1997 TIW  */
+/*    Fixed if/else bug, replaced stopmsg with pstopmsg */
+
+/* 09 Mar 1997 TIW/GGM  */
+/*    Added support for if/else */
+
+/* 30 Jun 1996 TIW  */
+/*    Removed function names if TESTFP not defined to save memory      */
+/*    Function fStkFloor added to support new 'floor' function         */
+/*    Function fStkCeil  added to support new 'ceil'  function         */
+/*    Function fStkTrunc added to support new 'trunc' function         */
+/*    Function fStkRound added to support new 'round' function         */
+
 /* 15 Feb 1995 CAE  */
 /*    added safety tests to pointer conversion code  */
 /*    added the capability for functions to require 4 free regs  */
@@ -86,7 +99,7 @@
 /* ******************************************************************* */
 
 /* Uncomment the next line to enable debug messages.  */
-/* --#define TESTFP 1  */
+/* #define TESTFP 1 */
 
 /* Use startup parameter "debugflag=324" to show debug messages after  */
 /*    compiling with above #define uncommented.  */
@@ -96,15 +109,10 @@
 
 #include <string.h>
 #include <ctype.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <float.h>
 #include <time.h>
-#ifndef XFRACT
-#include <dos.h>
-#endif
-#include "fractint.h"
-#include "mpmath.h"
+
+  /* see Fractint.c for a description of the "include"  hierarchy */
+#include "port.h"
 #include "prototyp.h"
 
 /* global data  */
@@ -114,7 +122,7 @@ struct fls far *pfls = (struct fls far *)0;
 
 /* not moved to PROTOTYPE.H because these only communicate within
    PARSER.C and other parser modules */
-   
+
 extern union Arg *Arg1, *Arg2;
 extern double _1_, _2_;
 extern union Arg s[20], far * far *Store, far * far *Load;
@@ -125,12 +133,13 @@ extern int InitLodPtr, InitStoPtr, InitOpPtr, LastInitOp;
 extern void (far * far *f)(void);
 extern char far compiled_fn_1[];
 extern char far compiled_fn_2[];
-
+extern JUMP_CONTROL_ST far *jump_control;
+extern int uses_jump, jump_index;
 int fFormula(void);
 
 typedef void OLD_FN(void);  /* old C functions  */
 
-OLD_FN  StkLod, StkClr, StkSto, EndInit;
+OLD_FN  StkLod, StkClr, StkSto, EndInit, StkJumpLabel;
 OLD_FN  dStkAdd, dStkSub, dStkMul, dStkDiv;
 OLD_FN  dStkSqr, dStkMod;
 OLD_FN  dStkSin, dStkCos, dStkSinh, dStkCosh, dStkCosXX;
@@ -147,6 +156,11 @@ OLD_FN  dStkSqrt;
 OLD_FN  dStkASin, dStkACos, dStkASinh, dStkACosh;
 OLD_FN  dStkATanh, dStkATan;
 OLD_FN  dStkCAbs;
+OLD_FN  dStkFloor;
+OLD_FN  dStkCeil;
+OLD_FN  dStkTrunc;
+OLD_FN  dStkRound;
+OLD_FN  StkJump, dStkJumpOnTrue, dStkJumpOnFalse;
 
 typedef void (near NEW_FN)(void);  /* new 387-only ASM functions  */
 
@@ -204,6 +218,8 @@ NEW_FN  fStkSqrt;
 NEW_FN  fStkASin, fStkACos, fStkASinh, fStkACosh;
 NEW_FN  fStkATanh, fStkATan;
 NEW_FN  fStkCAbs;
+NEW_FN  fStkFloor, fStkCeil, fStkTrunc, fStkRound; /* rounding functions */
+NEW_FN  fStkJump, fStkJumpOnTrue, fStkJumpOnFalse, fStkJumpLabel; /* flow */
 
 /* check to see if a const is being loaded  */
 /* the really awful hack below gets the first char of the name  */
@@ -235,33 +251,46 @@ NEW_FN  fStkCAbs;
 #define PARM1 v[1].a
 #define PARM2 v[2].a
 #define PARM3 v[8].a
-#define MAX_ARGS 100  /* maximum memory variables  */
 #define MAX_STACK 8   /* max # of stack register avail  */
 
 #ifdef TESTFP
+int pstopmsg(int x,char far *msg)
+{
+   static FILE *fp = NULL;
+   if(fp == NULL)
+      fp = fopen("fpdebug.txt","w");
+   if(fp)
+   {
+      fprintf(fp,"%Fs\n",msg);
+      fflush(fp);
+   }
+   return(x); /* just to quiet warnings */   
+}
 
-#define DBUGMSG(x,y) if (debugflag==324 ) stopmsg((x), (y) )
+#define stopmsg pstopmsg
+
+#define DBUGMSG(x,y) if (debugflag==324 || debugflag==322 ) stopmsg((x), (y))
 #define DBUGMSG1(x,y,p) \
-      if (debugflag==324 ){ \
+      if (debugflag==324 || debugflag==322 ){ \
          sprintf(cDbgMsg, (y), (p) ); \
          stopmsg((x), cDbgMsg ); \
       }
 #define DBUGMSG2(x,y,p,q) \
-      if (debugflag==324 ){ \
+      if (debugflag==324 || debugflag==322 ){ \
          sprintf(cDbgMsg, (y), (p), (q) ); \
          stopmsg((x), cDbgMsg ); \
       }
 #define DBUGMSG3(x,y,p,q,r) \
-      if (debugflag==324 ){ \
+      if (debugflag==324 || debugflag==322 ){ \
          sprintf(cDbgMsg, (y), (p), (q), (r) ); \
          stopmsg((x), cDbgMsg ); \
       }
 #define DBUGMSG4(x,y,p,q,r,s) \
-      if (debugflag==324 ){ \
+      if (debugflag==324 || debugflag==322 ){ \
          sprintf(cDbgMsg, (y), (p), (q), (r), (s) ); \
          stopmsg((x), cDbgMsg ); \
       }
-
+#define FNAME(a,b,c,d,e,f) a,b,c,d,e,f    /* use the function name string */
 #else
 
 #define DBUGMSG(x,y)
@@ -269,7 +298,7 @@ NEW_FN  fStkCAbs;
 #define DBUGMSG2(x,y,p,q)
 #define DBUGMSG3(x,y,p,q,r)
 #define DBUGMSG4(x,y,p,q,r,s)
-
+#define FNAME(a,b,c,d,e,f) b,c,d,e,f    /* don't use the function name string */
 #endif /* TESTFP */
 
 #define FN_LOD            0
@@ -319,28 +348,39 @@ NEW_FN  fStkCAbs;
 #define FN_ATANH         44
 #define FN_ATAN          45
 #define FN_CABS          46
+#define FN_FLOOR         47
+#define FN_CEIL          48
+#define FN_TRUNC         49
+#define FN_ROUND         50
+#define FN_JUMP          51
+#define FN_JUMP_ON_TRUE  52
+#define FN_JUMP_ON_FALSE 53
+#define FN_JUMP_LABEL    54
+
 
 /* number of "old" functions in the table.  */
 /* these are the ones that the parser outputs  */
 
-#define LAST_OLD_FN   FN_CABS
+#define LAST_OLD_FN   FN_JUMP_LABEL
 #define NUM_OLD_FNS   LAST_OLD_FN + 1
 
 /* total number of functions in the table.  */
 
-#define LAST_FN          FN_CABS
+#define LAST_FN          FN_JUMP_LABEL
 #define NUM_FNS          LAST_FN + 1
 
 static unsigned char
    realstkcnt,   /* how many scalars are really on stack  */
    stkcnt,       /* # scalars on FPU stack  */
-   cvtptrx,      /* subscript of next free entry in pfls  */
    lastsqrused,  /* was lastsqr loaded in the formula?  */
    lastsqrreal,  /* was lastsqr stored explicitly in the formula?  */
    p1const,      /* is p1 a constant?  */
    p2const,      /* ...and p2?  */
    p3const;      /* ...and p3?  */
 
+static unsigned int
+   cvtptrx;      /* subscript of next free entry in pfls  */
+
 static void (near *prevfptr )(void);  /* previous function pointer  */
 
 /* the entries in this table must be in the same order as  */
@@ -348,8 +388,9 @@ static void (near *prevfptr )(void);  /* previous function pointer  */
 /* this table is searched sequentially  */
 struct fn_entry {
 
+#ifdef TESTFP
    char far *fname;  /* function name  */
-
+#endif
    void (far *infn)(void);  /* 'old' function pointer  */
          /* (infn points to an operator fn in parser.c)  */
 
@@ -366,53 +407,61 @@ struct fn_entry {
 
 } static far afe[NUM_OLD_FNS] = {  /* array of function entries  */
 
-   {"Lod",     StkLod,      fStkLod,    0, 2, +2 },          /*  0  */
-   {"Clr",     StkClr,      fStkClr1,   0, 0,  CLEAR_STK },  /*  1  */
-   {"+",       dStkAdd,     fStkAdd,    4, 0, -2 },          /*  2  */
-   {"-",       dStkSub,     fStkSub,    4, 0, -2 },          /*  3  */
-   {"*",       dStkMul,     fStkMul,    4, 2, -2 },          /*  4  */
-   {"/",       dStkDiv,     fStkDiv,    4, 2, -2 },          /*  5  */
-   {"Sto",     StkSto,      fStkSto,    2, 0,  0 },          /*  6  */
-   {"Sqr",     dStkSqr,     fStkSqr,    2, 2,  0 },          /*  7  */
-   {":",       EndInit,     fStkEndInit,0, 0,  CLEAR_STK },  /*  8  */
-   {"Mod",     dStkMod,     fStkMod,    2, 0,  0 },          /*  9  */
-   {"<=",      dStkLTE,     fStkLTE,    4, 0, -2 },          /* 10  */
-   {"Sin",     dStkSin,     fStkSin,    2, 2,  0 },          /* 11  */
-   {"Cos",     dStkCos,     fStkCos,    2, 2,  0 },          /* 12  */
-   {"Sinh",    dStkSinh,    fStkSinh,   2, 2,  0 },          /* 13  */
-   {"Cosh",    dStkCosh,    fStkCosh,   2, 2,  0 },          /* 14  */
-   {"Cosxx",   dStkCosXX,   fStkCosXX,  2, 2,  0 },          /* 15  */
-   {"Tan",     dStkTan,     fStkTan,    2, 2,  0 },          /* 16  */
-   {"Tanh",    dStkTanh,    fStkTanh,   2, 2,  0 },          /* 17  */
-   {"CoTan",   dStkCoTan,   fStkCoTan,  2, 2,  0 },          /* 18  */
-   {"CoTanh",  dStkCoTanh,  fStkCoTanh, 2, 2,  0 },          /* 19  */
-   {"Log",     dStkLog,     fStkLog,    2, 2,  0 },          /* 20  */
-   {"Exp",     dStkExp,     fStkExp,    2, 2,  0 },          /* 21  */
-   {"^",       dStkPwr,     fStkPwr,    4, 2, -2 },          /* 22  */
-   {"<",       dStkLT,      fStkLT,     4, 0, -2 },          /* 23  */
-   {"Flip",    dStkFlip,    fStkFlip,   2, 0,  0 },          /* 24  */
-   {"Real",    dStkReal,    fStkReal,   2, 0,  0 },          /* 25  */
-   {"Imag",    dStkImag,    fStkImag,   2, 0,  0 },          /* 26  */
-   {"Conj",    dStkConj,    fStkConj,   2, 0,  0 },          /* 27  */
-   {"Neg",     dStkNeg,     fStkNeg,    2, 0,  0 },          /* 28  */
-   {"Abs",     dStkAbs,     fStkAbs,    2, 0,  0 },          /* 29  */
-   {"Recip",   dStkRecip,   fStkRecip,  2, 2,  0 },          /* 30  */
-   {"Ident",   StkIdent,    fStkIdent,  2, 0,  0 },          /* 31  */
-   {">",       dStkGT,      fStkGT,     4, 0, -2 },          /* 32  */
-   {">=",      dStkGTE,     fStkGTE,    4, 0, -2 },          /* 33  */
-   {"!=",      dStkNE,      fStkNE,     4, 0, -2 },          /* 34  */
-   {"==",      dStkEQ,      fStkEQ,     4, 0, -2 },          /* 35  */
-   {"&&",      dStkAND,     fStkAND,    4, 0, -2 },          /* 36  */
-   {"||",      dStkOR,      fStkOR,     4, 0, -2 },          /* 37  */
-   {"Zero",    dStkZero,    fStkZero,   2, 0,  0 },          /* 38  */
-   {"Sqrt",    dStkSqrt,    fStkSqrt,   2, 2,  0 },          /* 39  */
-   {"ASin",    dStkASin,    fStkASin,   2, 4,  0 },          /* 40  */
-   {"ACos",    dStkACos,    fStkACos,   2, 4,  0 },          /* 41  */
-   {"ASinh",   dStkASinh,   fStkASinh,  2, 4,  0 },          /* 42  */
-   {"ACosh",   dStkACosh,   fStkACosh,  2, 4,  0 },          /* 43  */
-   {"ATanh",   dStkATanh,   fStkATanh,  2, 4,  0 },          /* 44  */
-   {"ATan",    dStkATan,    fStkATan,   2, 4,  0 },          /* 45  */
-   {"CAbs",    dStkCAbs,    fStkCAbs,   2, 0,  0 }           /* 46  */
+   {FNAME("Lod",     StkLod,      fStkLod,    0, 2, +2) },          /*  0  */
+   {FNAME("Clr",     StkClr,      fStkClr1,   0, 0,  CLEAR_STK) },  /*  1  */
+   {FNAME("+",       dStkAdd,     fStkAdd,    4, 0, -2) },          /*  2  */
+   {FNAME("-",       dStkSub,     fStkSub,    4, 0, -2) },          /*  3  */
+   {FNAME("*",       dStkMul,     fStkMul,    4, 2, -2) },          /*  4  */
+   {FNAME("/",       dStkDiv,     fStkDiv,    4, 2, -2) },          /*  5  */
+   {FNAME("Sto",     StkSto,      fStkSto,    2, 0,  0) },          /*  6  */
+   {FNAME("Sqr",     dStkSqr,     fStkSqr,    2, 2,  0) },          /*  7  */
+   {FNAME(":",       EndInit,     fStkEndInit,0, 0,  CLEAR_STK) },  /*  8  */
+   {FNAME("Mod",     dStkMod,     fStkMod,    2, 0,  0) },          /*  9  */
+   {FNAME("<=",      dStkLTE,     fStkLTE,    4, 0, -2) },          /* 10  */
+   {FNAME("Sin",     dStkSin,     fStkSin,    2, 2,  0) },          /* 11  */
+   {FNAME("Cos",     dStkCos,     fStkCos,    2, 2,  0) },          /* 12  */
+   {FNAME("Sinh",    dStkSinh,    fStkSinh,   2, 2,  0) },          /* 13  */
+   {FNAME("Cosh",    dStkCosh,    fStkCosh,   2, 2,  0) },          /* 14  */
+   {FNAME("Cosxx",   dStkCosXX,   fStkCosXX,  2, 2,  0) },          /* 15  */
+   {FNAME("Tan",     dStkTan,     fStkTan,    2, 2,  0) },          /* 16  */
+   {FNAME("Tanh",    dStkTanh,    fStkTanh,   2, 2,  0) },          /* 17  */
+   {FNAME("CoTan",   dStkCoTan,   fStkCoTan,  2, 2,  0) },          /* 18  */
+   {FNAME("CoTanh",  dStkCoTanh,  fStkCoTanh, 2, 2,  0) },          /* 19  */
+   {FNAME("Log",     dStkLog,     fStkLog,    2, 2,  0) },          /* 20  */
+   {FNAME("Exp",     dStkExp,     fStkExp,    2, 2,  0) },          /* 21  */
+   {FNAME("^",       dStkPwr,     fStkPwr,    4, 2, -2) },          /* 22  */
+   {FNAME("<",       dStkLT,      fStkLT,     4, 0, -2) },          /* 23  */
+   {FNAME("Flip",    dStkFlip,    fStkFlip,   2, 0,  0) },          /* 24  */
+   {FNAME("Real",    dStkReal,    fStkReal,   2, 0,  0) },          /* 25  */
+   {FNAME("Imag",    dStkImag,    fStkImag,   2, 0,  0) },          /* 26  */
+   {FNAME("Conj",    dStkConj,    fStkConj,   2, 0,  0) },          /* 27  */
+   {FNAME("Neg",     dStkNeg,     fStkNeg,    2, 0,  0) },          /* 28  */
+   {FNAME("Abs",     dStkAbs,     fStkAbs,    2, 0,  0) },          /* 29  */
+   {FNAME("Recip",   dStkRecip,   fStkRecip,  2, 2,  0) },          /* 30  */
+   {FNAME("Ident",   StkIdent,    fStkIdent,  2, 0,  0) },          /* 31  */
+   {FNAME(">",       dStkGT,      fStkGT,     4, 0, -2) },          /* 32  */
+   {FNAME(">=",      dStkGTE,     fStkGTE,    4, 0, -2) },          /* 33  */
+   {FNAME("!=",      dStkNE,      fStkNE,     4, 0, -2) },          /* 34  */
+   {FNAME("==",      dStkEQ,      fStkEQ,     4, 0, -2) },          /* 35  */
+   {FNAME("&&",      dStkAND,     fStkAND,    4, 0, -2) },          /* 36  */
+   {FNAME("||",      dStkOR,      fStkOR,     4, 0, -2) },          /* 37  */
+   {FNAME("Zero",    dStkZero,    fStkZero,   2, 0,  0) },          /* 38  */
+   {FNAME("Sqrt",    dStkSqrt,    fStkSqrt,   2, 2,  0) },          /* 39  */
+   {FNAME("ASin",    dStkASin,    fStkASin,   2, 4,  0) },          /* 40  */
+   {FNAME("ACos",    dStkACos,    fStkACos,   2, 4,  0) },          /* 41  */
+   {FNAME("ASinh",   dStkASinh,   fStkASinh,  2, 4,  0) },          /* 42  */
+   {FNAME("ACosh",   dStkACosh,   fStkACosh,  2, 4,  0) },          /* 43  */
+   {FNAME("ATanh",   dStkATanh,   fStkATanh,  2, 4,  0) },          /* 44  */
+   {FNAME("ATan",    dStkATan,    fStkATan,   2, 4,  0) },          /* 45  */
+   {FNAME("CAbs",    dStkCAbs,    fStkCAbs,   2, 0,  0) },          /* 46  */
+   {FNAME("Floor",   dStkFloor,   fStkFloor,  2, 0,  0) },          /* 47  */
+   {FNAME("Ceil",    dStkCeil,    fStkCeil,   2, 0,  0) },          /* 48  */
+   {FNAME("Trunc",   dStkTrunc,   fStkTrunc,  2, 0,  0) },          /* 49  */
+   {FNAME("Round",   dStkRound,   fStkRound,  2, 0,  0) },          /* 50  */
+   {FNAME("Jump",        StkJump,         fStkJump,       0, 0, 0)},/* 51  */
+   {FNAME("JumpOnTrue",  dStkJumpOnTrue,  fStkJumpOnTrue, 2, 0, 0)},/* 52  */
+   {FNAME("JumpOnFalse", dStkJumpOnFalse, fStkJumpOnFalse,2, 0, 0)},/* 53  */
+   {FNAME("JumpLabel",   StkJumpLabel,    fStkJumpLabel,  0, 0, 0)} /* 54  */
 };
 
 #ifdef COMPILER
@@ -710,7 +759,7 @@ awful_error:
          ffptr = fStkStoDbl;
       }
       else if (prevfptr == fStkLod ){ /* have found  lod (*add)  */
-         --cvtptrx;	/*  ? *lod (add)  */
+         --cvtptrx;     /*  ? *lod (add)  */
          if (FNPTR(cvtptrx-1) == fStkPush2 ){
             DBUGMSG(0, "*push load (add) -> (*plodadd),stk+=2" );
             REMOVE_PUSH;
@@ -978,7 +1027,7 @@ awful_error:
    /* ******************************************************************** */
    else if (ffptr == fStkDiv ){
 
-      if (prevfptr == fStkLodRealC && vsp < MAX_ARGS - 1 ){
+      if (prevfptr == fStkLodRealC && vsp < Max_Args - 1 ){
          /* have found a divide by a real constant  */
          /*  and there is space to create a new one  */
          /* lodrealc ? (*div)  */
@@ -1246,7 +1295,7 @@ SkipOptimizer:  /* -------------  end of optimizer ----------------------- */
    FNPTR(cvtptrx++) = prevfptr = ffptr;
 #ifdef TESTFP
    prevstkcnt = stkcnt;
-#endif   
+#endif
    if (Delta == CLEAR_STK ){
       realstkcnt = stkcnt = 0;
    }
@@ -1261,11 +1310,64 @@ SkipOptimizer:  /* -------------  end of optimizer ----------------------- */
    return 1;  /* return 1 for success  */
 }
 
-extern int fform_per_pixel(void);	/* these fns are in parsera.asm  */
+int fpfill_jump_struct(void)
+{ /* Completes all entries in jump structure. Returns 1 on error) */
+  /* On entry, jump_index is the number of jump functions in the formula*/
+   int i = 0;
+   int checkforelse = 0;
+   NEW_FN near * JumpFunc;
+   int find_new_func = 1;
+   JUMP_PTRS_ST jump_data[MAX_JUMPS];
+
+   for (OpPtr = 0; OpPtr < (int) LastOp; OpPtr++) {
+      if(find_new_func) {
+         switch (jump_control[i].type) {
+            case 1:
+               JumpFunc = fStkJumpOnFalse;
+               break;
+            case 2:
+               checkforelse = !checkforelse;
+               if(checkforelse)
+                  JumpFunc = fStkJump;
+               else
+                  JumpFunc = fStkJumpOnFalse;
+               break;
+            case 3:
+               JumpFunc = fStkJump;
+               break;
+            case 4:
+               JumpFunc = fStkJumpLabel;
+               break;
+            default:
+               break;
+         }
+         find_new_func = 0;
+      }
+      if(pfls[OpPtr].function == JumpFunc) {
+         jump_data[i].JumpOpPtr = OpPtr*4;
+         i++;
+         find_new_func = 1;
+      }
+   }
+
+      /* Following for safety only; all should always be false */
+   if(i != jump_index || jump_control[i - 1].type != 4
+           || jump_control[0].type != 1) {
+      return 1;
+   }
+
+   while(i > 0) {
+      i--;
+      i = fill_if_group(i, jump_data);
+   }
+   return i < 0 ? 1 : 0;
+}
+
+extern int fform_per_pixel(void);       /* these fns are in parsera.asm  */
 extern int BadFormula(void);
 extern void (far Img_Setup )(void);
 
-int CvtStk() {	/* convert the array of ptrs  */
+int CvtStk() {  /* convert the array of ptrs  */
    extern char FormName[];
    void (far *ftst)(void);
    void (near *ntst)(void);
@@ -1325,7 +1427,7 @@ int CvtStk() {	/* convert the array of ptrs  */
    }
 
    prevfptr = (void (near *)(void))0;
-   realstkcnt = stkcnt = cvtptrx = 0;
+   cvtptrx = realstkcnt = stkcnt = 0;
 
    for (OpPtr = LodPtr = StoPtr = 0; OpPtr < (int)LastOp; OpPtr++) {
       ftst = f[OpPtr];
@@ -1426,7 +1528,8 @@ skipfinalopt:  /* -------------- end of final optimizations ------------ */
    LASTSQR.d.y = 0.0;  /* do this once per image  */
 
    /* now change the pointers  */
-   if (FormName[0] != 0 ){ /* but only if parse succeeded  */
+   if (FormName[0] != 0 &&
+        (uses_jump == 0 || fpfill_jump_struct() == 0)){ /* but only if parse succeeded  */
       curfractalspecific->per_pixel = fform_per_pixel;
       curfractalspecific->orbitcalc = fFormula;
    }
