@@ -1,12 +1,14 @@
+
+#ifndef PROTOTYP_H
+#define PROTOTYP_H
+
 /* includes needed to define the prototypes */
 
-#include <stdio.h>
 #include "mpmath.h"
+#include "big.h"
 #include "fractint.h"
-#ifndef PORT_H
-#include "port.h"
-#endif
 #include "helpcom.h"
+#include "externs.h"
 
 /*  calcmand -- assembler file prototypes */
 
@@ -53,11 +55,15 @@ extern int near asmlREALbailout(void);
 extern int near asmlIMAGbailout(void);
 extern int near asmlORbailout(void);
 extern int near asmlANDbailout(void);
+extern int near asmlMANHbailout(void);
+extern int near asmlMANRbailout(void);
 extern int near asm386lMODbailout(void);
 extern int near asm386lREALbailout(void);
 extern int near asm386lIMAGbailout(void);
 extern int near asm386lORbailout(void);
 extern int near asm386lANDbailout(void);
+extern int near asm386lMANHbailout(void);
+extern int near asm386lMANRbailout(void);
 extern int FManOWarfpFractal( void );
 extern int FJuliafpFractal( void );
 extern int FBarnsley1FPFractal( void );
@@ -68,6 +74,8 @@ extern int near asmfpREALbailout(void);
 extern int near asmfpIMAGbailout(void);
 extern int near asmfpORbailout(void);
 extern int near asmfpANDbailout(void);
+extern int near asmfpMANHbailout(void);
+extern int near asmfpMANRbailout(void);
 
 /*  general -- assembler file prototypes */
 
@@ -80,19 +88,27 @@ extern  int    cdecl far_strlen( char far *);
 extern  int    cdecl far_strnicmp(char far *, char far *,int);
 extern  void   cdecl far_strcpy( char far *, char far *);
 extern  int    cdecl far_strcmp( char far *, char far *);
-extern  void   cdecl far_stricmp(char far *, char far *);
+extern  int    cdecl far_strcmp( char far *, char far *);
+extern  int    cdecl far_stricmp(char far *, char far *);
 extern  void   cdecl far_strcat( char far *, char far *);
-extern  void   cdecl far_memset( VOIDFARPTR , int      , int);
+extern  void   cdecl far_memset( VOIDFARPTR , int      , unsigned);
 extern  void   cdecl far_memcpy( VOIDFARPTR , VOIDFARPTR , int);
 extern  int    cdecl far_memcmp( VOIDFARPTR , VOIDFARPTR , int);
 extern  void   cdecl far_memicmp(VOIDFARPTR , VOIDFARPTR , int);
+extern  BYTE far *cdecl emmquery(void);
+extern  unsigned int cdecl emmgetfree(void);
+extern  unsigned int cdecl emmallocate(unsigned int);
 extern  void   cdecl emmdeallocate(unsigned int);
 extern  void   cdecl emmgetpage(unsigned int, unsigned int);
 extern  void   cdecl emmclearpage(unsigned int, unsigned int);
+extern  unsigned int *cdecl xmmquery(void);
+extern  unsigned int cdecl xmmlongest(void);
+extern  unsigned int cdecl xmmallocate(unsigned int);
+extern  void   cdecl xmmdeallocate(unsigned int);
+extern  unsigned int cdecl xmmreallocate(unsigned int, unsigned int);
+extern  unsigned int cdecl xmmmoveextended(struct XMM_Move *);
 extern  int    cdecl keypressed(void);
 extern  long   cdecl readticker( void );
-extern  void   cdecl emmdeallocate(unsigned int);
-extern  void   cdecl xmmdeallocate(unsigned int);
 extern  void   cdecl snd( int );
 extern  void   cdecl nosnd( void );
 extern  void   cdecl initasmvars( void );
@@ -106,7 +122,6 @@ extern  void   cdecl delay( int );
 extern  int    cdecl farread(int, VOIDFARPTR, unsigned);
 extern  int    cdecl farwrite(int, VOIDFARPTR, unsigned);
 extern  long   cdecl normalize(char far *);
-extern  unsigned int cdecl xmmmoveextended(struct XMM_Move *);
 extern  void   cdecl erasesegment(int, int);
 extern  int    cdecl IITCoPro( void );
 extern  int    cdecl F4x4Check( void );
@@ -118,12 +133,6 @@ extern  unsigned int cdecl fromextra( unsigned int, char *, int );
 extern  unsigned int cdecl toextra( unsigned int, char *, int );
 extern  void   cdecl load_mat(double (*)[4]);
 extern  VOIDFARPTR cdecl farmemalloc(long);
-extern  unsigned int *cdecl xmmquery(void);
-extern  BYTE far *cdecl emmquery(void);
-extern  unsigned int cdecl emmgetfree(void);
-extern  unsigned int cdecl emmallocate(unsigned int);
-extern  unsigned int cdecl emmallocate(unsigned int);
-extern  unsigned int cdecl xmmallocate(unsigned int);
 extern  void   mult_vec_iit(VECTOR);
 
 /*  mpmath_a -- assembler file prototypes */
@@ -188,7 +197,9 @@ extern void   cdecl scrollup(int, int);
 extern void   cdecl home(void);
 extern BYTE far *cdecl  findfont(int);
 extern int _fastcall getcolor(int, int);
-extern void _fastcall putcolor(int, int, int);
+extern void _fastcall putcolor_a(int, int, int);
+extern void gettruecolor(int, int, int*, int*, int*);
+extern void puttruecolor(int, int, int, int, int);
 extern int  out_line(BYTE *, int);
 extern void   (*swapsetup)(void);
 
@@ -275,6 +286,7 @@ extern void dopause(int);
 /*  decoder -- C file prototypes */
 
 extern short decoder(short );
+extern void set_byte_buff(BYTE *ptr);
 
 /*  diskvid -- C file prototypes */
 
@@ -302,7 +314,7 @@ extern VOIDPTR mem_alloc(unsigned size);
 void putrow(int x, int y, int width, char *buff);
 void getrow(int x, int y, int width, char *buff);
 void mem_init(VOIDPTR block, unsigned size);
-void xhline(int x, int y, int width, int color);
+/* void hline(int x, int y, int width, int color); */
 int Cursor_WaitKey(void);
 void Cursor_CheckBlink(void);
 #ifdef XFRACT
@@ -366,8 +378,12 @@ extern void _fastcall noplot(int ,int ,int );
 extern void fractal_floattobf(void);
 extern void adjust_cornerbf(void);
 extern char *typehasparm(int,int);
-extern void fill_dx_array();
-extern void fill_lx_array();
+extern void fill_dx_array(void);
+extern void fill_lx_array(void);
+extern int snd_open(void);
+extern void w_snd(int);
+extern void snd_time_write(void);
+extern void close_snd(void);
 
 /*  fractals -- C file prototypes */
 
@@ -454,7 +470,9 @@ extern int MarksMandelPwrFractal(void);
 extern int TimsErrorfpFractal(void);
 extern int TimsErrorFractal(void);
 extern int CirclefpFractal(void);
-extern int VLFractal(void);
+extern int VLfpFractal(void);
+extern int VLSetup(void);
+extern int EscherfpFractal(void);
 extern int long_julia_per_pixel(void);
 extern int long_richard8_per_pixel(void);
 extern int long_mandel_per_pixel(void);
@@ -538,16 +556,22 @@ extern int near fpREALbailout(void);
 extern int near fpIMAGbailout(void);
 extern int near fpORbailout(void);
 extern int near fpANDbailout(void);
+extern int near fpMANHbailout(void);
+extern int near fpMANRbailout(void);
 extern int near bnMODbailout(void);
 extern int near bnREALbailout(void);
 extern int near bnIMAGbailout(void);
 extern int near bnORbailout(void);
 extern int near bnANDbailout(void);
+extern int near bnMANHbailout(void);
+extern int near bnMANRbailout(void);
 extern int near bfMODbailout(void);
 extern int near bfREALbailout(void);
 extern int near bfIMAGbailout(void);
 extern int near bfORbailout(void);
 extern int near bfANDbailout(void);
+extern int near bfMANHbailout(void);
+extern int near bfMANRbailout(void);
 extern int ant(void);
 extern int LongPhoenixFractal(void);
 extern int PhoenixFractal(void);
@@ -569,6 +593,7 @@ extern int mandphoenix_per_pixel(void);
 /*  fractint -- C file prototypes */
 
 extern void main(int argc,char **argv );
+extern int elapsed_time(int);
 
 /*  framain2 -- C file prototypes */
 
@@ -582,7 +607,7 @@ extern int sound_line(BYTE *,int );
 extern int sound_line(unsigned char *pixels,int linelen);
 #ifndef XFRACT
 extern int timer(int,int (*subrtn)(),...);
-extern int _cdecl matherr(struct exception *);
+extern int _cdecl _matherr(struct exception *);
 #else
 extern int timer();
 extern int XZoomWaiting;
@@ -658,6 +683,7 @@ extern int    EnQueueFloat    (float,  float);
 extern int line3d(BYTE *,unsigned int );
 extern int _fastcall targa_color(int ,int ,int );
 extern int targa_validate(char *);
+extern int startdisk1(char *, FILE *, int);
 
 /*  loadfdos -- C file prototypes */
 
@@ -670,8 +696,7 @@ extern void set_if_old_bif(void);
 extern int fgetwindow(void);
 extern void backwards_v18(void);
 extern void backwards_v19(void);
-extern int fix_bof(void);
-extern int fix_period_bof(void);
+extern int check_back(void);
 
 /*  loadmap -- C file prototypes */
 
@@ -737,6 +762,8 @@ extern void make_mig(unsigned int, unsigned int);
 extern int getprecdbl(int);
 extern int getprecbf(int);
 extern int getprecbf_mag(void);
+extern void parse_comments(char *value);
+extern void init_comments(void);
 
 /*  miscres -- C file prototypes */
 
@@ -754,12 +781,14 @@ extern void showtrig(char *);
 extern int set_trig_array(int ,char *);
 extern void set_trig_pointers(int );
 extern int tab_display(void);
-extern int endswithslash(char *);
+extern int endswithslash(char far *);
 extern int ifsload(void);
-extern int find_file_item(char *,char *,FILE **);
+extern int find_file_item(char *,char *,FILE **, int);
 extern int file_gets(char *,int ,FILE *);
 extern void roundfloatd(double *);
+extern void fix_inversion(double *);
 extern int ungetakey(int);
+extern void get_calculation_time(char *msgout);
 
 /*  mpmath_c -- C file prototypes */
 
@@ -780,6 +809,7 @@ extern struct MPC cmplx2MPC(_CMPLX );
 extern void setMPfunctions(void );
 extern _CMPLX ComplexPower(_CMPLX ,_CMPLX );
 extern void SetupLogTable(void );
+extern long logtablecalc(long);
 extern long far ExpFloat14(long );
 extern int ComplexNewtonSetup(void );
 extern int ComplexNewton(void );
@@ -944,6 +974,18 @@ extern void lStkCAbs(void );
 extern void dStkSqrt(void );
 extern void mStkSqrt(void );
 extern void lStkSqrt(void );
+extern void dStkFloor(void );
+extern void mStkFloor(void );
+extern void lStkFloor(void );
+extern void dStkCeil(void );
+extern void mStkCeil(void );
+extern void lStkCeil(void );
+extern void dStkTrunc(void );
+extern void mStkTrunc(void );
+extern void lStkTrunc(void );
+extern void dStkRound(void );
+extern void mStkRound(void );
+extern void lStkRound(void );
 extern void (*mtrig0)(void);
 extern void (*mtrig1)(void);
 extern void (*mtrig2)(void);
@@ -956,19 +998,20 @@ extern int whichfn(char *,int );
 extern int CvtStk(void);
 #ifndef XFRACT
 extern void (far *isfunct(char *,int ))(void );
+extern int fFormula(void );
 #else
 extern void (far *isfunct(char *,int ))();
 #endif
 extern void RecSortPrec(void );
-extern int ParseStr(char *);
 extern int Formula(void );
+extern int BadFormula(void );
 extern int form_per_pixel(void );
-extern char *FindFormula(char *);
 extern int RunForm(char *);
 extern int fpFormulaSetup(void );
 extern int intFormulaSetup(void );
 extern void init_misc(void);
 extern void free_workarea(void);
+extern int fill_if_group(int endif_index, JUMP_PTRS_ST *jump_data);
 
 /*  plot3d -- C file prototypes */
 
@@ -1050,7 +1093,7 @@ extern int strncasecmp(char far *,char far *,int );
 extern int main_menu(int );
 extern int input_field(int ,int ,char *,int ,int ,int ,int (*)(int));
 extern int field_prompt(int ,char far *,char far *,char *,int ,int (*)(int));
-extern int thinking(int ,char *);
+extern int thinking(int ,char far *);
 extern void clear_screen(void );
 extern int savegraphics(void);
 extern int restoregraphics(void);
@@ -1183,5 +1226,4 @@ extern _BFCMPLX *ComplexPower_bf(_BFCMPLX *t, _BFCMPLX *xx, _BFCMPLX *yy);
 /*#define DEBUG */
 #endif
 
-#include "externs.h"
-
+#endif
