@@ -7,19 +7,13 @@
    file (.pot) in version 15.  Delete this code after a few more revs.
 */
 
-#include <stdio.h>
-#include "fractint.h"
-#include "targa_lc.h"
+
+  /* see Fractint.c for a description of the "include"  hierarchy */
+#include "port.h"
 #include "prototyp.h"
+#include "targa_lc.h"
 
-extern char readname[]; 		/* file name		  */
-extern unsigned int boxx[];		/* write-line routines use this */
-extern int colors;
-extern int rowcount;
-
-static FILE *fptarga = NULL;		/* FILE pointer 	  */
-extern unsigned int height;		/* image height 	  */
-extern int (*outln)();
+static FILE *fptarga = NULL;            /* FILE pointer           */
 
 /* Main entry decoder */
 tgaview()
@@ -28,41 +22,40 @@ tgaview()
    int cs;
    unsigned int width;
    struct fractal_info info;
-   FILE *t16_open();
 
    if((fptarga = t16_open(readname, (int *)&width, (int *)&height, &cs, (U8 *)&info))==NULL)
       return(-1);
 
    rowcount = 0;
-   for (i=0; i<height; ++i)
+   for (i=0; i<(int)height; ++i)
    {
        t16_getline(fptarga, width, (U16 *)boxx);
-       if ((*outln)(boxx,width))
+       if ((*outln)((void *)boxx,width))
        {
-	  fclose(fptarga);
-	  fptarga = NULL;
-	  return(-1);
+          fclose(fptarga);
+          fptarga = NULL;
+          return(-1);
        }
        if (keypressed())
        {
-	  fclose(fptarga);
-	  fptarga = NULL;
-	  return(-1);
+          fclose(fptarga);
+          fptarga = NULL;
+          return(-1);
        }
    }
    fclose(fptarga);
    fptarga = NULL;
    return(0);
 }
+
 /* Outline function for 16 bit data with 8 bit fudge */
 outlin16(BYTE *buffer,int linelen)
 {
-    extern int rowcount;
-    U16 *buf;
     int i;
+    U16 *buf;
     buf = (U16 *)buffer;
     for(i=0;i<linelen;i++)
-       putcolor(i,rowcount,buf[i]>>8); 
+       putcolor(i,rowcount,buf[i]>>8);
     rowcount++;
     return(0);
 }
