@@ -33,10 +33,10 @@
 #include <sys/file.h>
 #endif
 #include <fcntl.h>
-#include "fractint.h"
-#include "prototyp.h"
 #include "helpdefs.h"
-#ifdef linux
+#include "port.h"
+#include "prototyp.h"
+#ifdef LINUX
 #define FNDELAY O_NDELAY
 #endif
 #ifdef __SVR4
@@ -241,7 +241,7 @@ UnixInit()
     initdacbox();
 
     if (!simple_input) {
-	  signal(SIGINT,(sigfunc *)goodbye);
+	  signal(SIGINT,(SignalHandler)goodbye);
     }
     signal(SIGFPE, fpe_handler);
     /*
@@ -2068,12 +2068,12 @@ xgetfont()
 void
 shell_to_dos()
 {
-    sigfunc *sigint;
+    SignalHandler sigint;
     char *shell;
     char *argv[2];
     int pid, donepid;
 
-    sigint = (sigfunc *)signal(SIGINT, SIG_IGN);
+    sigint = (SignalHandler)signal(SIGINT, SIG_IGN);
     shell = getenv("SHELL");
     if (shell==NULL) {
 	shell = SHELL;
@@ -2121,7 +2121,7 @@ shell_to_dos()
 	fcntl(0,F_SETFL,FNDELAY);
     }
 
-    signal(SIGINT, (sigfunc *)sigint);
+    signal(SIGINT, (SignalHandler)sigint);
     putchar('\n');
 }
 
@@ -2146,7 +2146,7 @@ schedulealarm(soon)
 int soon;
 {
     if (!fastmode) return;
-    signal(SIGALRM, (sigfunc *)setredrawscreen);
+    signal(SIGALRM, (SignalHandler)setredrawscreen);
     if (soon) {
 	alarm(1);
     } else {
